|Doc Status| |Coverage| |GitHub license| |Python Lint|

^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Ganondorf
=========

A federated GAN for Medical Image to Image Segmentation







Data References and Usage
=========================


This repository includes data from the Brain-Tumor-Progression collection and the QIN-BRAIN-DSC-MRI collection, both of which have been published by `The Cancer Imaging Archive`. The original data has been modified to combine all the DICM image slices into one Gzipped NIfTI for each series, for the Brain-Tumor-Progression images the files were renamed Pre.... and Post... for the first and second scan respectivly and for QIN-BRAIN-DSC-MRI the files were renamed as Scan and Mask. The images have all been resized to 256 X 256 using Nearest Neighbors interpolation and the number of slices has been reset to 22; the majority of the Images had 22 slices and those with more had slices dropped to match the look of those with only 22 slices. 

Users of this data must abide by the TCIA Data Usage Policy and the `Creative Commons Attribution 3.0 Unported License`_ under which it has been published. Any publications discussing these data should include references to the following:

  Data Citation
    Schmainda KM, Prah M (2018). Data from Brain-Tumor-Progression. The Cancer Imaging Archive. http://doi.org/10.7937/K9/TCIA.2018.15quzvnb

    Kathleen M Schmainda, Melissa A Prah, Jennifer M Connelly, Scott D Rand. (2016). Glioma DSC-MRI Perfusion Data with Standard Imaging and ROIs [ Dataset ] . The Cancer Imaging Archive. DOI: 10.7937/K9/TCIA.2016.5DI84Js8

  Publication Citation
    Schmainda KM, Prah MA, Rand SD, Liu Y, Logan B, Muzi M, Rane SD, Da X, Yen YF, Kalpathy-Cramer J, Chenevert TL, Hoff B, Ross B, Cao Y, Aryal MP, Erickson B, Korfiatis P, Dondlinger T, Bell L, Hu L, Kinahan PE, Quarles CC. (2018). Multisite Concordance of DSC-MRI Analysis for Brain Tumors: Results of a National Cancer Institute Quantitative Imaging Network Collaborative Project. American Journal of Neuroradiology, 39(6), 1008–1016. DOI: 10.3174/ajnr.a5675


  TCIA Citation
    Clark K, Vendt B, Smith K, Freymann J, Kirby J, Koppel P, Moore S, Phillips S, Maffitt D, Pringle M, Tarbox L, Prior F. The Cancer Imaging Archive (TCIA): Maintaining and Operating a Public Information Repository, Journal of Digital Imaging, Volume 26, Number 6, December, 2013, pp 1045-1057. https://doi.org/10.1007/s10278-013-9622-7


.. _`The Cancer Imaging Archive`: https://cancerimagingarchive.net
.. _`Creative Commons Attribution 3.0 Unported License`: https://creativecommons.org/licenses/by/3.0/



.. |Doc Status| image:: https://readthedocs.org/projects/ganondorf/badge/?version=latest
  :target: https://ganondorf.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. |Coverage| image:: https://codecov.io/gh/SagaraBattousai/ganondorf/branch/master/graph/badge.svg?token=8V9SGTAQLM
  :target: https://codecov.io/gh/SagaraBattousai/ganondorf
  :alt: Code Coverage Status

.. |Python Testing| image:: https://github.com/SagaraBattousai/ganondorf/workflows/Python%20Testing/badge.svg
  :target: https://github.com/SagaraBattousai/ganondorf/actions?query=workflow%3APython%20Testing"><img
  :alt: GitHub Actions Python Code Testing

..
  .. |Ganondorf Build| image:: https://github.com/SagaraBattousai/ganondorf/workflows/Python%20Testing/badge.svg
    :target: https://github.com/SagaraBattousai/ganondorf/actions?query=workflow%3APython%20Testing"><img
    :alt: GitHub Actions Python Code Testing
..
  .. |Python Wheel| image:: https://github.com/SagaraBattousai/ganondorf/workflows/Python%20Wheel/badge.svg
    :target: https://github.com/SagaraBattousai/ganondorf/actions?query=workflow%3APython%20Wheel"><img
    :alt: GitHub Actions Python Wheel Package Building

.. |Python Lint| image:: https://github.com/SagaraBattousai/ganondorf/workflows/Python%20Lint/badge.svg
  :target: https://github.com/SagaraBattousai/ganondorf/actions?query=workflow%3APython%20Lint"><img
  :alt: GitHub Actions Python Code Linting













.. |GitHub license| image:: https://img.shields.io/github/license/sagaraBattousai/ganondorf?logo=data:image/svg+xml;base64, 
